Administration
Model name | Add link | Change or view list link
--- | --- | ---
Log entries | Add | Change

Approve_Workflow_Test_App
Model name | Add link | Change or view list link
--- | --- | ---
Approve test models | Add | Change

Authentication and Authorization
Model name | Add link | Change or view list link
--- | --- | ---
Groups | Add | Change
Users | Add | Change

Test_App
Model name | Add link | Change or view list link
--- | --- | ---
Color field test models | Add | Change
Create or update test models | Add | Change
Translated models | Add | Change
Translated slug test models | Add | Change
Validate length translationss | Add | Change

Feature Flags
Model name | Add link | Change or view list link
--- | --- | ---
Feature Flags values DEMO |  | View
Manage Feature Flags |  | View

Generic Model Filter
Model name | Add link | Change or view list link
--- | --- | ---
Generic model item filter |  | View

Pseudo App 1
Model name | Add link | Change or view list link
--- | --- | ---
Demo View 1 |  | View
Demo View 2 |  | View

Pseudo App 2
Model name | Add link | Change or view list link
--- | --- | ---
Demo View 3 |  | View